[![Lint and test fadge](https://github.com/adxsrc/fadge/actions/workflows/python-test.yml/badge.svg)](https://github.com/adxsrc/fadge/actions/workflows/python-test.yml)
[![Publish fadge to PyPI](https://github.com/adxsrc/fadge/actions/workflows/python-publish.yml/badge.svg)](https://github.com/adxsrc/fadge/actions/workflows/python-publish.yml)

# `Fadge`

Fast Automatic Differential GEometry (`Fadge`) uses
[Google's JAX](https://github.com/google/jax)
for differential geometry.

![Kerr-Schild Horizons](horizons.png)
